/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example Template
*
*/

#include <stdbool.h>
#include "nrf_gpio.h"
#include "boards.h"


/**
 * @brief Function for application main entry.
 */
int main(void)
{
    // Configure LED to indicated LPCOMP level crossing
    nrf_gpio_cfg_output(LED_1);
    
    // Configure LPCOMP:
    // Use AIN2 pin (P0.01) as input.
    // Choose VDD * 1/4 as reference voltage
    // Generate an event on every crossing (both up and down) of the reference voltage
    NRF_LPCOMP->PSEL = (LPCOMP_PSEL_PSEL_AnalogInput2 << LPCOMP_PSEL_PSEL_Pos);
    NRF_LPCOMP->REFSEL = (LPCOMP_REFSEL_REFSEL_SupplyFourEighthsPrescaling << LPCOMP_REFSEL_REFSEL_Pos);
    NRF_LPCOMP->ANADETECT = (LPCOMP_ANADETECT_ANADETECT_Cross << LPCOMP_ANADETECT_ANADETECT_Pos);
 
    // Configure GPIOTE ouput task:
    // Set GPIOTE channel 0 in task mode
    // Use LED_1 (P0.21)
    // Toggle pin on every event
    // Initial level of pin is high
    NRF_GPIOTE->CONFIG[0] = (GPIOTE_CONFIG_MODE_Task << GPIOTE_CONFIG_MODE_Pos) |  
                            (LED_1 << GPIOTE_CONFIG_PSEL_Pos) |
                            (GPIOTE_CONFIG_POLARITY_Toggle << GPIOTE_CONFIG_POLARITY_Pos) |
                            (GPIOTE_CONFIG_OUTINIT_High << GPIOTE_CONFIG_OUTINIT_Pos);
    
    // Configure PPI cannel 0 to connect LPCOMP event and GPIOTE Task
    // Event End Point is LPCOMP cross event
    // Task End Point is GPIOTE Led
    // Enabl the PPI 0 channel
    NRF_PPI->CH[0].EEP = (uint32_t)&NRF_LPCOMP->EVENTS_CROSS;
    NRF_PPI->CH[0].TEP = (uint32_t)&NRF_GPIOTE->TASKS_OUT[0];
    NRF_PPI->CHEN |= (PPI_CHEN_CH0_Enabled << PPI_CHEN_CH0_Pos);
    
    
    // Enable and start LPCOMP
    NRF_LPCOMP->ENABLE = 1;
    NRF_LPCOMP->TASKS_START = 1;
    
    
    while (true)
    {
        __WFE();// Go to sleep and do nothing
    }
}
/** @} */
